==> ejc-settlementmanage-impl-3.0.0-20230510.092559-248-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementResponsibilityEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算责任书评审主表
 *
 * @author generator
 *
 */
 @TableName("ejc_settlementmanage_settlement_responsibility")
public class SettlementResponsibilityEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="actual_commencement_date")
    private java.util.Date actualCommencementDate; // 实际开工日期
    @TableField(value="actual_completion_date")
    private java.util.Date actualCompletionDate; // 实际竣工日期
    @TableField(value="contract_price")
    private java.math.BigDecimal contractPrice; // 合同造价
    @TableField(value="expect_cost")
    private java.math.BigDecimal expectCost; // 预计成本
    @TableField(value="expect_settlement_value")
    private java.math.BigDecimal expectSettlementValue; // 预计结算值
    @TableField(value="expect_profit_margin")
    private java.math.BigDecimal expectProfitMargin; // 预计利润率
    @TableField(value="surrender_rate")
    private java.math.BigDecimal surrenderRate; // 项目管理目标责任书总和上缴利润率
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人id
    @TableField(value="agent_department")
    private java.lang.Long agentDepartment; // 经办人部门
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value = "original_id")
    private java.lang.Long originalId;
    @TableField(value="settlement_basic_value")
    private BigDecimal settlementBasicValue; // 结算基本值
    @TableField(value="settlement_hope_value")
    private BigDecimal settlementHopeValue; // 结算期望值
    @TableField(value="profit_overtop_basicval")
    private BigDecimal profitOvertopBasicval; // 提成高于基本值%
    @TableField(value="profit_overtop_hopeval")
    private BigDecimal profitOvertopHopeval; // 提成高于期望值%

    public BigDecimal getSettlementBasicValue() {
        return settlementBasicValue;
    }

    public void setSettlementBasicValue(BigDecimal settlementBasicValue) {
        this.settlementBasicValue = settlementBasicValue;
    }

    public BigDecimal getSettlementHopeValue() {
        return settlementHopeValue;
    }

    public void setSettlementHopeValue(BigDecimal settlementHopeValue) {
        this.settlementHopeValue = settlementHopeValue;
    }

    public BigDecimal getProfitOvertopBasicval() {
        return profitOvertopBasicval;
    }

    public void setProfitOvertopBasicval(BigDecimal profitOvertopBasicval) {
        this.profitOvertopBasicval = profitOvertopBasicval;
    }

    public BigDecimal getProfitOvertopHopeval() {
        return profitOvertopHopeval;
    }

    public void setProfitOvertopHopeval(BigDecimal profitOvertopHopeval) {
        this.profitOvertopHopeval = profitOvertopHopeval;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 实际开工日期
     */
    public java.util.Date getActualCommencementDate() {
        return actualCommencementDate;
    }

    /**
     * 实际开工日期
     */
    public void setActualCommencementDate(java.util.Date actualCommencementDate) {
        this.actualCommencementDate = actualCommencementDate;
    }
    /**
     * 实际竣工日期
     */
    public java.util.Date getActualCompletionDate() {
        return actualCompletionDate;
    }

    /**
     * 实际竣工日期
     */
    public void setActualCompletionDate(java.util.Date actualCompletionDate) {
        this.actualCompletionDate = actualCompletionDate;
    }
    /**
     * 合同造价
     */
    public java.math.BigDecimal getContractPrice() {
        return contractPrice;
    }

    /**
     * 合同造价
     */
    public void setContractPrice(java.math.BigDecimal contractPrice) {
        this.contractPrice = contractPrice;
    }
    /**
     * 预计成本
     */
    public java.math.BigDecimal getExpectCost() {
        return expectCost;
    }

    /**
     * 预计成本
     */
    public void setExpectCost(java.math.BigDecimal expectCost) {
        this.expectCost = expectCost;
    }
    /**
     * 预计结算值
     */
    public java.math.BigDecimal getExpectSettlementValue() {
        return expectSettlementValue;
    }

    /**
     * 预计结算值
     */
    public void setExpectSettlementValue(java.math.BigDecimal expectSettlementValue) {
        this.expectSettlementValue = expectSettlementValue;
    }
    /**
     * 预计利润率
     */
    public java.math.BigDecimal getExpectProfitMargin() {
        return expectProfitMargin;
    }

    /**
     * 预计利润率
     */
    public void setExpectProfitMargin(java.math.BigDecimal expectProfitMargin) {
        this.expectProfitMargin = expectProfitMargin;
    }
    /**
     * 项目管理目标责任书总和上缴利润率
     */
    public java.math.BigDecimal getSurrenderRate() {
        return surrenderRate;
    }

    /**
     * 项目管理目标责任书总和上缴利润率
     */
    public void setSurrenderRate(java.math.BigDecimal surrenderRate) {
        this.surrenderRate = surrenderRate;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人部门
     */
    public java.lang.Long getAgentDepartment() {
        return agentDepartment;
    }

    /**
     * 经办人部门
     */
    public void setAgentDepartment(java.lang.Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20250822.092935-320-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementResponsibilityEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算责任书评审主表
 *
 * @author generator
 *
 */
 @TableName("ejc_settlementmanage_settlement_responsibility")
public class SettlementResponsibilityEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="actual_commencement_date")
    private java.util.Date actualCommencementDate; // 实际开工日期
    @TableField(value="actual_completion_date")
    private java.util.Date actualCompletionDate; // 实际竣工日期
    @TableField(value="contract_price")
    private java.math.BigDecimal contractPrice; // 合同造价
    @TableField(value="expect_cost")
    private java.math.BigDecimal expectCost; // 预计成本
    @TableField(value="expect_settlement_value")
    private java.math.BigDecimal expectSettlementValue; // 预计结算值
    @TableField(value="expect_profit_margin")
    private java.math.BigDecimal expectProfitMargin; // 预计利润率
    @TableField(value="surrender_rate")
    private java.math.BigDecimal surrenderRate; // 项目管理目标责任书总和上缴利润率
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人id
    @TableField(value="agent_department")
    private java.lang.Long agentDepartment; // 经办人部门
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value = "original_id")
    private java.lang.Long originalId;
    @TableField(value="settlement_basic_value")
    private BigDecimal settlementBasicValue; // 结算基本值
    @TableField(value="settlement_hope_value")
    private BigDecimal settlementHopeValue; // 结算期望值
    @TableField(value="profit_overtop_basicval")
    private BigDecimal profitOvertopBasicval; // 提成高于基本值%
    @TableField(value="profit_overtop_hopeval")
    private BigDecimal profitOvertopHopeval; // 提成高于期望值%
    @TableField(value="contract_category_id")
    private Long contractCategoryId; // 合同类别
    @TableField(value="contract_category_name")
    private String contractCategoryName; // 合同类别名称

    public Long getContractCategoryId() {
        return contractCategoryId;
    }

    public void setContractCategoryId(Long contractCategoryId) {
        this.contractCategoryId = contractCategoryId;
    }

    public String getContractCategoryName() {
        return contractCategoryName;
    }

    public void setContractCategoryName(String contractCategoryName) {
        this.contractCategoryName = contractCategoryName;
    }

    public BigDecimal getSettlementBasicValue() {
        return settlementBasicValue;
    }

    public void setSettlementBasicValue(BigDecimal settlementBasicValue) {
        this.settlementBasicValue = settlementBasicValue;
    }

    public BigDecimal getSettlementHopeValue() {
        return settlementHopeValue;
    }

    public void setSettlementHopeValue(BigDecimal settlementHopeValue) {
        this.settlementHopeValue = settlementHopeValue;
    }

    public BigDecimal getProfitOvertopBasicval() {
        return profitOvertopBasicval;
    }

    public void setProfitOvertopBasicval(BigDecimal profitOvertopBasicval) {
        this.profitOvertopBasicval = profitOvertopBasicval;
    }

    public BigDecimal getProfitOvertopHopeval() {
        return profitOvertopHopeval;
    }

    public void setProfitOvertopHopeval(BigDecimal profitOvertopHopeval) {
        this.profitOvertopHopeval = profitOvertopHopeval;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 实际开工日期
     */
    public java.util.Date getActualCommencementDate() {
        return actualCommencementDate;
    }

    /**
     * 实际开工日期
     */
    public void setActualCommencementDate(java.util.Date actualCommencementDate) {
        this.actualCommencementDate = actualCommencementDate;
    }
    /**
     * 实际竣工日期
     */
    public java.util.Date getActualCompletionDate() {
        return actualCompletionDate;
    }

    /**
     * 实际竣工日期
     */
    public void setActualCompletionDate(java.util.Date actualCompletionDate) {
        this.actualCompletionDate = actualCompletionDate;
    }
    /**
     * 合同造价
     */
    public java.math.BigDecimal getContractPrice() {
        return contractPrice;
    }

    /**
     * 合同造价
     */
    public void setContractPrice(java.math.BigDecimal contractPrice) {
        this.contractPrice = contractPrice;
    }
    /**
     * 预计成本
     */
    public java.math.BigDecimal getExpectCost() {
        return expectCost;
    }

    /**
     * 预计成本
     */
    public void setExpectCost(java.math.BigDecimal expectCost) {
        this.expectCost = expectCost;
    }
    /**
     * 预计结算值
     */
    public java.math.BigDecimal getExpectSettlementValue() {
        return expectSettlementValue;
    }

    /**
     * 预计结算值
     */
    public void setExpectSettlementValue(java.math.BigDecimal expectSettlementValue) {
        this.expectSettlementValue = expectSettlementValue;
    }
    /**
     * 预计利润率
     */
    public java.math.BigDecimal getExpectProfitMargin() {
        return expectProfitMargin;
    }

    /**
     * 预计利润率
     */
    public void setExpectProfitMargin(java.math.BigDecimal expectProfitMargin) {
        this.expectProfitMargin = expectProfitMargin;
    }
    /**
     * 项目管理目标责任书总和上缴利润率
     */
    public java.math.BigDecimal getSurrenderRate() {
        return surrenderRate;
    }

    /**
     * 项目管理目标责任书总和上缴利润率
     */
    public void setSurrenderRate(java.math.BigDecimal surrenderRate) {
        this.surrenderRate = surrenderRate;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人部门
     */
    public java.lang.Long getAgentDepartment() {
        return agentDepartment;
    }

    /**
     * 经办人部门
     */
    public void setAgentDepartment(java.lang.Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
}
